import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ClusterRoleBindingConfig extends TerraformMetaArguments {
    /** metadata block */
    readonly metadata: ClusterRoleBindingMetadata[];
    /** role_ref block */
    readonly roleRef: ClusterRoleBindingRoleRef[];
    /** subject block */
    readonly subject: ClusterRoleBindingSubject[];
}
export interface ClusterRoleBindingMetadata {
    /** An unstructured key value map stored with the clusterRoleBinding that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations */
    readonly annotations?: {
        [key: string]: string;
    };
    /** Map of string keys and values that can be used to organize and categorize (scope and select) the clusterRoleBinding. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels */
    readonly labels?: {
        [key: string]: string;
    };
    /** Name of the clusterRoleBinding, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
    readonly name?: string;
}
export interface ClusterRoleBindingRoleRef {
    /** The API group of the user. The only value possible at the moment is `rbac.authorization.k8s.io`. */
    readonly apiGroup: string;
    /** The kind of resource. */
    readonly kind: string;
    /** The name of the User to bind to. */
    readonly name: string;
}
export interface ClusterRoleBindingSubject {
    /** The API group of the subject resource. */
    readonly apiGroup?: string;
    /** The kind of resource. */
    readonly kind: string;
    /** The name of the resource to bind to. */
    readonly name: string;
    /** The Namespace of the subject resource. */
    readonly namespace?: string;
}
export declare class ClusterRoleBinding extends TerraformResource {
    constructor(scope: Construct, id: string, config: ClusterRoleBindingConfig);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _metadata;
    get metadata(): ClusterRoleBindingMetadata[];
    set metadata(value: ClusterRoleBindingMetadata[]);
    private _roleRef;
    get roleRef(): ClusterRoleBindingRoleRef[];
    set roleRef(value: ClusterRoleBindingRoleRef[]);
    private _subject;
    get subject(): ClusterRoleBindingSubject[];
    set subject(value: ClusterRoleBindingSubject[]);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
