import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface CsiDriverConfig extends TerraformMetaArguments {
    /** metadata block */
    readonly metadata: CsiDriverMetadata[];
    /** spec block */
    readonly spec?: CsiDriverSpec[];
}
export interface CsiDriverMetadata {
    /** An unstructured key value map stored with the csi driver that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations */
    readonly annotations?: {
        [key: string]: string;
    };
    /** Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided. This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency */
    readonly generateName?: string;
    /** Map of string keys and values that can be used to organize and categorize (scope and select) the csi driver. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels */
    readonly labels?: {
        [key: string]: string;
    };
    /** Name of the csi driver, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
    readonly name?: string;
}
export interface CsiDriverSpec {
    /** Indicates if the CSI volume driver requires an attach operation */
    readonly attachRequired: boolean;
    /** Indicates that the CSI volume driver requires additional pod information (like podName, podUID, etc.) during mount operations */
    readonly podInfoOnMount?: boolean;
    /** Defines what kind of volumes this CSI volume driver supports */
    readonly volumeLifecycleModes?: string[];
}
export declare class CsiDriver extends TerraformResource {
    constructor(scope: Construct, id: string, config: CsiDriverConfig);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _metadata;
    get metadata(): CsiDriverMetadata[];
    set metadata(value: CsiDriverMetadata[]);
    private _spec?;
    get spec(): CsiDriverSpec[] | undefined;
    set spec(value: CsiDriverSpec[] | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
