import { Construct } from 'constructs';
import { TerraformProvider } from 'cdktf';
export interface KubernetesProviderConfig {
    /** PEM-encoded client certificate for TLS authentication. */
    readonly clientCertificate?: string;
    /** PEM-encoded client certificate key for TLS authentication. */
    readonly clientKey?: string;
    /** PEM-encoded root certificates bundle for TLS authentication. */
    readonly clusterCaCertificate?: string;
    readonly configContext?: string;
    readonly configContextAuthInfo?: string;
    readonly configContextCluster?: string;
    /** Path to the kube config file, defaults to ~/.kube/config */
    readonly configPath?: string;
    /** The hostname (in form of URI) of Kubernetes master. */
    readonly host?: string;
    /** Whether server should be accessed without verifying the TLS certificate. */
    readonly insecure?: boolean;
    /** Load local kubeconfig. */
    readonly loadConfigFile?: boolean;
    /** The password to use for HTTP basic authentication when accessing the Kubernetes master endpoint. */
    readonly password?: string;
    /** Token to authenticate an service account */
    readonly token?: string;
    /** The username to use for HTTP basic authentication when accessing the Kubernetes master endpoint. */
    readonly username?: string;
    /** Alias name */
    readonly alias?: string;
    /** exec block */
    readonly exec?: KubernetesProviderExec[];
}
export interface KubernetesProviderExec {
    readonly apiVersion: string;
    readonly args?: string[];
    readonly command: string;
    readonly env?: {
        [key: string]: string;
    };
}
export declare class KubernetesProvider extends TerraformProvider {
    constructor(scope: Construct, id: string, config?: KubernetesProviderConfig);
    private _clientCertificate?;
    get clientCertificate(): string | undefined;
    set clientCertificate(value: string | undefined);
    private _clientKey?;
    get clientKey(): string | undefined;
    set clientKey(value: string | undefined);
    private _clusterCaCertificate?;
    get clusterCaCertificate(): string | undefined;
    set clusterCaCertificate(value: string | undefined);
    private _configContext?;
    get configContext(): string | undefined;
    set configContext(value: string | undefined);
    private _configContextAuthInfo?;
    get configContextAuthInfo(): string | undefined;
    set configContextAuthInfo(value: string | undefined);
    private _configContextCluster?;
    get configContextCluster(): string | undefined;
    set configContextCluster(value: string | undefined);
    private _configPath?;
    get configPath(): string | undefined;
    set configPath(value: string | undefined);
    private _host?;
    get host(): string | undefined;
    set host(value: string | undefined);
    private _insecure?;
    get insecure(): boolean | undefined;
    set insecure(value: boolean | undefined);
    private _loadConfigFile?;
    get loadConfigFile(): boolean | undefined;
    set loadConfigFile(value: boolean | undefined);
    private _password?;
    get password(): string | undefined;
    set password(value: string | undefined);
    private _token?;
    get token(): string | undefined;
    set token(value: string | undefined);
    private _username?;
    get username(): string | undefined;
    set username(value: string | undefined);
    private _alias?;
    get alias(): string | undefined;
    set alias(value: string | undefined);
    private _exec?;
    get exec(): KubernetesProviderExec[] | undefined;
    set exec(value: KubernetesProviderExec[] | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
