import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface LimitRangeConfig extends TerraformMetaArguments {
    /** metadata block */
    readonly metadata: LimitRangeMetadata[];
    /** spec block */
    readonly spec?: LimitRangeSpec[];
}
export interface LimitRangeMetadata {
    /** An unstructured key value map stored with the limit range that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations */
    readonly annotations?: {
        [key: string]: string;
    };
    /** Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided. This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency */
    readonly generateName?: string;
    /** Map of string keys and values that can be used to organize and categorize (scope and select) the limit range. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels */
    readonly labels?: {
        [key: string]: string;
    };
    /** Name of the limit range, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
    readonly name?: string;
    /** Namespace defines the space within which name of the limit range must be unique. */
    readonly namespace?: string;
}
export interface LimitRangeSpecLimit {
    /** Default resource requirement limit value by resource name if resource limit is omitted. */
    readonly default?: {
        [key: string]: string;
    };
    /** The default resource requirement request value by resource name if resource request is omitted. */
    readonly defaultRequest?: {
        [key: string]: string;
    };
    /** Max usage constraints on this kind by resource name. */
    readonly max?: {
        [key: string]: string;
    };
    /** The named resource must have a request and limit that are both non-zero where limit divided by request is less than or equal to the enumerated value; this represents the max burst for the named resource. */
    readonly maxLimitRequestRatio?: {
        [key: string]: string;
    };
    /** Min usage constraints on this kind by resource name. */
    readonly min?: {
        [key: string]: string;
    };
    /** Type of resource that this limit applies to. */
    readonly type?: string;
}
export interface LimitRangeSpec {
    /** limit block */
    readonly limit?: LimitRangeSpecLimit[];
}
export declare class LimitRange extends TerraformResource {
    constructor(scope: Construct, id: string, config: LimitRangeConfig);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _metadata;
    get metadata(): LimitRangeMetadata[];
    set metadata(value: LimitRangeMetadata[]);
    private _spec?;
    get spec(): LimitRangeSpec[] | undefined;
    set spec(value: LimitRangeSpec[] | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
