import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface MutatingWebhookConfigurationConfig extends TerraformMetaArguments {
    /** metadata block */
    readonly metadata: MutatingWebhookConfigurationMetadata[];
    /** webhook block */
    readonly webhook: MutatingWebhookConfigurationWebhook[];
}
export interface MutatingWebhookConfigurationMetadata {
    /** An unstructured key value map stored with the mutating webhook configuration that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations */
    readonly annotations?: {
        [key: string]: string;
    };
    /** Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided. This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency */
    readonly generateName?: string;
    /** Map of string keys and values that can be used to organize and categorize (scope and select) the mutating webhook configuration. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels */
    readonly labels?: {
        [key: string]: string;
    };
    /** Name of the mutating webhook configuration, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
    readonly name?: string;
}
export interface MutatingWebhookConfigurationWebhookClientConfigService {
    /** `name` is the name of the service. Required */
    readonly name: string;
    /** `namespace` is the namespace of the service. Required */
    readonly namespace: string;
    /** `path` is an optional URL path which will be sent in any request to this service. */
    readonly path?: string;
    /** If specified, the port on the service that hosting webhook. Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive). */
    readonly port?: number;
}
export interface MutatingWebhookConfigurationWebhookClientConfig {
    /** `caBundle` is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used. */
    readonly caBundle?: string;
    /** `url` gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.
  
  The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
  
  Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
  
  The scheme must be "https"; the URL must begin with "https://".
  
  A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
  
  Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either. */
    readonly url?: string;
    /** service block */
    readonly service?: MutatingWebhookConfigurationWebhookClientConfigService[];
}
export interface MutatingWebhookConfigurationWebhookNamespaceSelectorMatchExpressions {
    /** The label key that the selector applies to. */
    readonly key?: string;
    /** A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`. */
    readonly operator?: string;
    /** An array of string values. If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch. */
    readonly values?: string[];
}
export interface MutatingWebhookConfigurationWebhookNamespaceSelector {
    /** A map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed. */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /** match_expressions block */
    readonly matchExpressions?: MutatingWebhookConfigurationWebhookNamespaceSelectorMatchExpressions[];
}
export interface MutatingWebhookConfigurationWebhookObjectSelectorMatchExpressions {
    /** The label key that the selector applies to. */
    readonly key?: string;
    /** A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`. */
    readonly operator?: string;
    /** An array of string values. If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch. */
    readonly values?: string[];
}
export interface MutatingWebhookConfigurationWebhookObjectSelector {
    /** A map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed. */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /** match_expressions block */
    readonly matchExpressions?: MutatingWebhookConfigurationWebhookObjectSelectorMatchExpressions[];
}
export interface MutatingWebhookConfigurationWebhookRule {
    readonly apiGroups: string[];
    readonly apiVersions: string[];
    /** Operations is the operations the admission hook cares about - CREATE, UPDATE, or * for all operations. If '*' is present, the length of the slice must be one. Required. */
    readonly operations: string[];
    readonly resources: string[];
    readonly scope?: string;
}
export interface MutatingWebhookConfigurationWebhook {
    /** AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects. API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy. */
    readonly admissionReviewVersions?: string[];
    /** FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Fail. */
    readonly failurePolicy?: string;
    /** matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
  
  - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.
  
  - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.
  
  Defaults to "Equivalent" */
    readonly matchPolicy?: string;
    /** The name of the admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required. */
    readonly name: string;
    /** reinvocationPolicy indicates whether this webhook should be called multiple times as part of a single admission evaluation. Allowed values are "Never" and "IfNeeded".
  
  Never: the webhook will not be called more than once in a single admission evaluation.
  
  IfNeeded: the webhook will be called at least one additional time as part of the admission evaluation if the object being admitted is modified by other admission plugins after the initial webhook call. Webhooks that specify this option *must* be idempotent, able to process objects they previously admitted. Note: * the number of additional invocations is not guaranteed to be exactly one. * if additional invocations result in further modifications to the object, webhooks are not guaranteed to be invoked again. * webhooks that use this option may be reordered to minimize the number of additional invocations. * to validate an object after all mutations are guaranteed complete, use a validating admission webhook instead.
  
  Defaults to "Never". */
    readonly reinvocationPolicy?: string;
    /** SideEffects states whether this webhook has side effects. Acceptable values are: None, NoneOnDryRun (webhooks created via v1beta1 may also specify Some or Unknown). Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission change and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some. */
    readonly sideEffects?: string;
    /** TimeoutSeconds specifies the timeout for this webhook. After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 10 seconds. */
    readonly timeoutSeconds?: number;
    /** client_config block */
    readonly clientConfig: MutatingWebhookConfigurationWebhookClientConfig[];
    /** namespace_selector block */
    readonly namespaceSelector?: MutatingWebhookConfigurationWebhookNamespaceSelector[];
    /** object_selector block */
    readonly objectSelector?: MutatingWebhookConfigurationWebhookObjectSelector[];
    /** rule block */
    readonly rule: MutatingWebhookConfigurationWebhookRule[];
}
export declare class MutatingWebhookConfiguration extends TerraformResource {
    constructor(scope: Construct, id: string, config: MutatingWebhookConfigurationConfig);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _metadata;
    get metadata(): MutatingWebhookConfigurationMetadata[];
    set metadata(value: MutatingWebhookConfigurationMetadata[]);
    private _webhook;
    get webhook(): MutatingWebhookConfigurationWebhook[];
    set webhook(value: MutatingWebhookConfigurationWebhook[]);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
