import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface PodDisruptionBudgetConfig extends TerraformMetaArguments {
    /** metadata block */
    readonly metadata: PodDisruptionBudgetMetadata[];
    /** spec block */
    readonly spec: PodDisruptionBudgetSpec[];
}
export interface PodDisruptionBudgetMetadata {
    /** An unstructured key value map stored with the pod disruption budget that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations */
    readonly annotations?: {
        [key: string]: string;
    };
    /** Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided. This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency */
    readonly generateName?: string;
    /** Map of string keys and values that can be used to organize and categorize (scope and select) the pod disruption budget. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels */
    readonly labels?: {
        [key: string]: string;
    };
    /** Name of the pod disruption budget, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
    readonly name?: string;
    /** Namespace defines the space within which name of the pod disruption budget must be unique. */
    readonly namespace?: string;
}
export interface PodDisruptionBudgetSpecSelectorMatchExpressions {
    /** The label key that the selector applies to. */
    readonly key?: string;
    /** A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`. */
    readonly operator?: string;
    /** An array of string values. If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch. */
    readonly values?: string[];
}
export interface PodDisruptionBudgetSpecSelector {
    /** A map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed. */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /** match_expressions block */
    readonly matchExpressions?: PodDisruptionBudgetSpecSelectorMatchExpressions[];
}
export interface PodDisruptionBudgetSpec {
    readonly maxUnavailable?: string;
    readonly minAvailable?: string;
    /** selector block */
    readonly selector: PodDisruptionBudgetSpecSelector[];
}
export declare class PodDisruptionBudget extends TerraformResource {
    constructor(scope: Construct, id: string, config: PodDisruptionBudgetConfig);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _metadata;
    get metadata(): PodDisruptionBudgetMetadata[];
    set metadata(value: PodDisruptionBudgetMetadata[]);
    private _spec;
    get spec(): PodDisruptionBudgetSpec[];
    set spec(value: PodDisruptionBudgetSpec[]);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
