import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface PriorityClassConfig extends TerraformMetaArguments {
    /** An arbitrary string that usually provides guidelines on when this priority class should be used. */
    readonly description?: string;
    /** Specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class. Only one PriorityClass can be marked as `globalDefault`. However, if more than one PriorityClasses exists with their `globalDefault` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority. */
    readonly globalDefault?: boolean;
    /** The value of this priority class. This is the actual priority that pods receive when they have the name of this class in their pod spec. */
    readonly value: number;
    /** metadata block */
    readonly metadata: PriorityClassMetadata[];
}
export interface PriorityClassMetadata {
    /** An unstructured key value map stored with the priority class that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations */
    readonly annotations?: {
        [key: string]: string;
    };
    /** Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided. This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency */
    readonly generateName?: string;
    /** Map of string keys and values that can be used to organize and categorize (scope and select) the priority class. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels */
    readonly labels?: {
        [key: string]: string;
    };
    /** Name of the priority class, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
    readonly name?: string;
}
export declare class PriorityClass extends TerraformResource {
    constructor(scope: Construct, id: string, config: PriorityClassConfig);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _globalDefault?;
    get globalDefault(): boolean | undefined;
    set globalDefault(value: boolean | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _value;
    get value(): number;
    set value(value: number);
    private _metadata;
    get metadata(): PriorityClassMetadata[];
    set metadata(value: PriorityClassMetadata[]);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
