import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ResourceQuotaConfig extends TerraformMetaArguments {
    /** metadata block */
    readonly metadata: ResourceQuotaMetadata[];
    /** spec block */
    readonly spec?: ResourceQuotaSpec[];
    /** timeouts block */
    readonly timeouts?: ResourceQuotaTimeouts;
}
export interface ResourceQuotaMetadata {
    /** An unstructured key value map stored with the resource quota that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations */
    readonly annotations?: {
        [key: string]: string;
    };
    /** Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided. This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency */
    readonly generateName?: string;
    /** Map of string keys and values that can be used to organize and categorize (scope and select) the resource quota. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels */
    readonly labels?: {
        [key: string]: string;
    };
    /** Name of the resource quota, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
    readonly name?: string;
    /** Namespace defines the space within which name of the resource quota must be unique. */
    readonly namespace?: string;
}
export interface ResourceQuotaSpec {
    /** The set of desired hard limits for each named resource. More info: http://releases.k8s.io/HEAD/docs/design/admission_control_resource_quota.md#admissioncontrol-plugin-resourcequota */
    readonly hard?: {
        [key: string]: string;
    };
    /** A collection of filters that must match each object tracked by a quota. If not specified, the quota matches all objects. */
    readonly scopes?: string[];
}
export interface ResourceQuotaTimeouts {
    readonly create?: string;
    readonly update?: string;
}
export declare class ResourceQuota extends TerraformResource {
    constructor(scope: Construct, id: string, config: ResourceQuotaConfig);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _metadata;
    get metadata(): ResourceQuotaMetadata[];
    set metadata(value: ResourceQuotaMetadata[]);
    private _spec?;
    get spec(): ResourceQuotaSpec[] | undefined;
    set spec(value: ResourceQuotaSpec[] | undefined);
    private _timeouts?;
    get timeouts(): ResourceQuotaTimeouts | undefined;
    set timeouts(value: ResourceQuotaTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
