import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface RoleBindingConfig extends TerraformMetaArguments {
    /** metadata block */
    readonly metadata: RoleBindingMetadata[];
    /** role_ref block */
    readonly roleRef: RoleBindingRoleRef[];
    /** subject block */
    readonly subject: RoleBindingSubject[];
}
export interface RoleBindingMetadata {
    /** An unstructured key value map stored with the roleBinding that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations */
    readonly annotations?: {
        [key: string]: string;
    };
    /** Map of string keys and values that can be used to organize and categorize (scope and select) the roleBinding. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels */
    readonly labels?: {
        [key: string]: string;
    };
    /** Name of the roleBinding, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
    readonly name?: string;
    /** Namespace defines the space within which name of the roleBinding must be unique. */
    readonly namespace?: string;
}
export interface RoleBindingRoleRef {
    /** The API group of the user. The only value possible at the moment is `rbac.authorization.k8s.io`. */
    readonly apiGroup: string;
    /** The kind of resource. */
    readonly kind: string;
    /** The name of the User to bind to. */
    readonly name: string;
}
export interface RoleBindingSubject {
    /** The API group of the subject resource. */
    readonly apiGroup?: string;
    /** The kind of resource. */
    readonly kind: string;
    /** The name of the resource to bind to. */
    readonly name: string;
    /** The Namespace of the subject resource. */
    readonly namespace?: string;
}
export declare class RoleBinding extends TerraformResource {
    constructor(scope: Construct, id: string, config: RoleBindingConfig);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _metadata;
    get metadata(): RoleBindingMetadata[];
    set metadata(value: RoleBindingMetadata[]);
    private _roleRef;
    get roleRef(): RoleBindingRoleRef[];
    set roleRef(value: RoleBindingRoleRef[]);
    private _subject;
    get subject(): RoleBindingSubject[];
    set subject(value: RoleBindingSubject[]);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
