import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface RoleConfig extends TerraformMetaArguments {
    /** metadata block */
    readonly metadata: RoleMetadata[];
    /** rule block */
    readonly rule: RoleRule[];
}
export interface RoleMetadata {
    /** An unstructured key value map stored with the role that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations */
    readonly annotations?: {
        [key: string]: string;
    };
    /** Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided. This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency */
    readonly generateName?: string;
    /** Map of string keys and values that can be used to organize and categorize (scope and select) the role. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels */
    readonly labels?: {
        [key: string]: string;
    };
    /** Name of the role, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
    readonly name?: string;
    /** Namespace defines the space within which name of the role must be unique. */
    readonly namespace?: string;
}
export interface RoleRule {
    /** Name of the APIGroup that contains the resources */
    readonly apiGroups: string[];
    /** White list of names that the rule applies to */
    readonly resourceNames?: string[];
    /** List of resources that the rule applies to */
    readonly resources: string[];
    /** List of Verbs that apply to ALL the ResourceKinds and AttributeRestrictions contained in this rule */
    readonly verbs: string[];
}
export declare class Role extends TerraformResource {
    constructor(scope: Construct, id: string, config: RoleConfig);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _metadata;
    get metadata(): RoleMetadata[];
    set metadata(value: RoleMetadata[]);
    private _rule;
    get rule(): RoleRule[];
    set rule(value: RoleRule[]);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
