import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface SecretConfig extends TerraformMetaArguments {
    /** A map of the secret data. */
    readonly data?: {
        [key: string]: string;
    };
    /** Type of secret */
    readonly type?: string;
    /** metadata block */
    readonly metadata: SecretMetadata[];
}
export interface SecretMetadata {
    /** An unstructured key value map stored with the secret that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations */
    readonly annotations?: {
        [key: string]: string;
    };
    /** Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided. This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency */
    readonly generateName?: string;
    /** Map of string keys and values that can be used to organize and categorize (scope and select) the secret. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels */
    readonly labels?: {
        [key: string]: string;
    };
    /** Name of the secret, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
    readonly name?: string;
    /** Namespace defines the space within which name of the secret must be unique. */
    readonly namespace?: string;
}
export declare class Secret extends TerraformResource {
    constructor(scope: Construct, id: string, config: SecretConfig);
    private _data?;
    get data(): {
        [key: string]: string;
    } | undefined;
    set data(value: {
        [key: string]: string;
    } | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _type?;
    get type(): string | undefined;
    set type(value: string | undefined);
    private _metadata;
    get metadata(): SecretMetadata[];
    set metadata(value: SecretMetadata[]);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
