import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ServiceAccountConfig extends TerraformMetaArguments {
    /** True to enable automatic mounting of the service account token */
    readonly automountServiceAccountToken?: boolean;
    /** image_pull_secret block */
    readonly imagePullSecret?: ServiceAccountImagePullSecret[];
    /** metadata block */
    readonly metadata: ServiceAccountMetadata[];
    /** secret block */
    readonly secret?: ServiceAccountSecret[];
    /** timeouts block */
    readonly timeouts?: ServiceAccountTimeouts;
}
export interface ServiceAccountImagePullSecret {
    /** Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
    readonly name?: string;
}
export interface ServiceAccountMetadata {
    /** An unstructured key value map stored with the service account that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations */
    readonly annotations?: {
        [key: string]: string;
    };
    /** Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided. This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency */
    readonly generateName?: string;
    /** Map of string keys and values that can be used to organize and categorize (scope and select) the service account. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels */
    readonly labels?: {
        [key: string]: string;
    };
    /** Name of the service account, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
    readonly name?: string;
    /** Namespace defines the space within which name of the service account must be unique. */
    readonly namespace?: string;
}
export interface ServiceAccountSecret {
    /** Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
    readonly name?: string;
}
export interface ServiceAccountTimeouts {
    readonly create?: string;
}
export declare class ServiceAccount extends TerraformResource {
    constructor(scope: Construct, id: string, config: ServiceAccountConfig);
    private _automountServiceAccountToken?;
    get automountServiceAccountToken(): boolean | undefined;
    set automountServiceAccountToken(value: boolean | undefined);
    get defaultSecretName(): string;
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _imagePullSecret?;
    get imagePullSecret(): ServiceAccountImagePullSecret[] | undefined;
    set imagePullSecret(value: ServiceAccountImagePullSecret[] | undefined);
    private _metadata;
    get metadata(): ServiceAccountMetadata[];
    set metadata(value: ServiceAccountMetadata[]);
    private _secret?;
    get secret(): ServiceAccountSecret[] | undefined;
    set secret(value: ServiceAccountSecret[] | undefined);
    private _timeouts?;
    get timeouts(): ServiceAccountTimeouts | undefined;
    set timeouts(value: ServiceAccountTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
