import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface StorageClassConfig extends TerraformMetaArguments {
    /** Indicates whether the storage class allow volume expand */
    readonly allowVolumeExpansion?: boolean;
    /** Persistent Volumes that are dynamically created by a storage class will have the mount options specified */
    readonly mountOptions?: string[];
    /** The parameters for the provisioner that should create volumes of this storage class */
    readonly parameters?: {
        [key: string]: string;
    };
    /** Indicates the type of the reclaim policy */
    readonly reclaimPolicy?: string;
    /** Indicates the type of the provisioner */
    readonly storageProvisioner: string;
    /** Indicates when volume binding and dynamic provisioning should occur */
    readonly volumeBindingMode?: string;
    /** metadata block */
    readonly metadata: StorageClassMetadata[];
}
export interface StorageClassMetadata {
    /** An unstructured key value map stored with the storage class that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations */
    readonly annotations?: {
        [key: string]: string;
    };
    /** Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided. This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency */
    readonly generateName?: string;
    /** Map of string keys and values that can be used to organize and categorize (scope and select) the storage class. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels */
    readonly labels?: {
        [key: string]: string;
    };
    /** Name of the storage class, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
    readonly name?: string;
}
export declare class StorageClass extends TerraformResource {
    constructor(scope: Construct, id: string, config: StorageClassConfig);
    private _allowVolumeExpansion?;
    get allowVolumeExpansion(): boolean | undefined;
    set allowVolumeExpansion(value: boolean | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _mountOptions?;
    get mountOptions(): string[] | undefined;
    set mountOptions(value: string[] | undefined);
    private _parameters?;
    get parameters(): {
        [key: string]: string;
    } | undefined;
    set parameters(value: {
        [key: string]: string;
    } | undefined);
    private _reclaimPolicy?;
    get reclaimPolicy(): string | undefined;
    set reclaimPolicy(value: string | undefined);
    private _storageProvisioner;
    get storageProvisioner(): string;
    set storageProvisioner(value: string);
    private _volumeBindingMode?;
    get volumeBindingMode(): string | undefined;
    set volumeBindingMode(value: string | undefined);
    private _metadata;
    get metadata(): StorageClassMetadata[];
    set metadata(value: StorageClassMetadata[]);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
